@@ -57,7 +57,7 @@ class HandWheel:
     def task(self):
         self.jog_speed = {}
         config = configparser.ConfigParser()
-        config.read(self.package.framework.machine.workspace + "/config/" + self.package.framework.machine.machine_path + "/machine.user")
+        config.read(self.package.framework.machine.workspace + "/configs/" + self.package.framework.machine.machine_path + "/machine.user")
         config_items = config.items("HANDWHEEL")
         for key, val in config_items:
             key = "EXTINFO_" + key
@@ -190,9 +190,8 @@ class HandWheel:
 
     def jog_count_value(self, jog):
         jog_length = 0
-        if len(self.jog_speed) > 0:
-            for i in jog:
-                jog_length = jog_length + i
+        for i in jog:
+            jog_length = jog_length + i
         return float(jog_length) / 100
 
     def get_jog_speed(self, axis):
@@ -213,14 +212,13 @@ class HandWheel:
 
     def str2hex(self, jog):
         data = 0
-        if len(self.jog_speed) > 0:
-            jog = jog.upper()
-            for c in jog:
-                tmp = ord(c)
-                if tmp <= ord("9"):
-                    data = data << 4
-                    data += tmp - ord("0")
-                elif ord("A") <= tmp <= ord("F"):
-                    data = data << 4
-                    data += tmp - ord("A") + 10
+        jog = jog.upper()
+        for c in jog:
+            tmp = ord(c)
+            if tmp <= ord("9"):
+                data = data << 4
+                data += tmp - ord("0")
+            elif ord("A") <= tmp <= ord("F"):
+                data = data << 4
+                data += tmp - ord("A") + 10
         return data
